UniqueKey

Trait UniqueKey 

pub trait UniqueKey {
    // Required method
    fn unique_key(&self) -> String;
}
A trait to uniquely identify values of the same type.

Required Methods

fn unique_key(&self) -> String

A string that uniquely identifies Self compared to other values of the same type.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl UniqueKey for MediaSource

Implementors