pub trait UniqueKey {
// Required method
fn unique_key(&self) -> String;
}Expand description
A trait to uniquely identify values of the same type.
Required Methods
Sourcefn unique_key(&self) -> String
fn unique_key(&self) -> String
A string that uniquely identifies Self compared to other values of
the same type.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".